@@ -54,7 +54,7 @@ class Apiview(object):
                 package = self.packer.pack_result(result)
             except Exception as error:
                 logger.exception("apiview process failed: {}".format(str(error)))
-                if not isinstance(error, bizerror.BizError):
+                if not isinstance(error, bizerror.BizErrorBase):
                     error = bizerror.BizError(error)
                 package = self.packer.pack_error(error)
             return JsonResponse(package, encoder=SimpleJsonEncoder, json_dumps_params={"ensure_ascii": False, "allow_nan": True, "sort_keys": True})
@@ -147,3 +147,15 @@ def rsa_decrypt(field, private_key):
         return functools.wraps(func)(wrapper)
     return wrapper_outer
 
+
+def meta_variable(variable_name, meta_name):
+    """Get variable from meta.
+    """
+    def wrapper_outer(func):
+        def wrapper(_django_apiview_view_instance):
+            view = _django_apiview_view_instance
+            value = view.request.META.get(meta_name, None)
+            view.data[variable_name] = value
+            return view.process(func)
+        return functools.wraps(func)(wrapper)
+    return wrapper_outer
